@@ -2,6 +2,8 @@ context("clhs-sp")
 
 test_that("clhs on a SpatialPointsDataFrame works", {
   
+  skip_if_not_installed("sp")
+  
   suppressWarnings(RNGversion("3.5.0"))
   set.seed(1)
   
@@ -16,7 +18,7 @@ test_that("clhs on a SpatialPointsDataFrame works", {
   spdf <- sp::SpatialPointsDataFrame(
     coords = df[, c("x", "y")],
     data = df[, c("a", "b", "c")],
-    proj4string = sp::CRS("+init=epsg:4326")
+    proj4string = sp::CRS("EPSG:4326")
   )
   
   res1 <- clhs(spdf, size = 5, iter = 100, progress = FALSE, simple = TRUE)
